#ifndef CGTKPKGCATVIEW_H
#define CGTKPKGCATVIEW_H

#include <gtkmm.h>
#include <map>
#include "common_fun.h"
using namespace Common;

// Implements a TreeView widget specifically for displaying package
// categories in zendo. Use GtkPkgCatView::RebuildList to change
// the style of the list.
// See COPYING for license information.

class CGtkPkgCatView : public Gtk::ScrolledWindow
{
public:
	CGtkPkgCatView();
	void		BuildNormalList(packagemap_t& packages);
	void		BuildMirrorCatList(packagemap_t& packages);
	Gtk::TreeView*	GetTreeView();
	Glib::ustring	GetCurrentCategory();
protected:
	Gtk::TreeView				_TreeView;
	Gtk::TreeModel::ColumnRecord		_ColumnRecord;
	Glib::RefPtr<Gtk::ListStore>		_RefModel;
	Gtk::TreeModelColumn<Glib::ustring>	_ColPkgCat;
};

CGtkPkgCatView::CGtkPkgCatView()
{
	set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
	add(_TreeView);

	_ColumnRecord.add(_ColPkgCat);
	_RefModel = Gtk::ListStore::create(_ColumnRecord);
	_TreeView.set_model(_RefModel);
	_TreeView.append_column("Categories", _ColPkgCat);
}

void CGtkPkgCatView::BuildNormalList(packagemap_t& packages)
{
	_RefModel->clear();
	Gtk::TreeModel::Row	_row = *(_RefModel->append());
	_row[_ColPkgCat] = "All";
	_TreeView.get_selection()->select(_row);	// Start off with the "All" category selected

	// Iterate through the package map and create a temporary map
	// of categories, so that we only use the ones we need.
	std::map<Glib::ustring, int>	_tmpmap;
	for ( packagemap_t::iterator _iter = packages.begin(); _iter != packages.end(); ++_iter ) {
		Glib::ustring	_loc = _iter->second.location;
		if ( !_loc.find("extra/") ) _loc.erase(0, 6);

		if ( !_loc.find("local://") )	_tmpmap["Local Mirror"] = 1;
		else if ( _loc == "xap" )	_tmpmap["Applications"] = 1;
		else if ( _loc == "ap" )	_tmpmap["Applications (CLI)"] = 1;
		else if ( _loc == "a" )		_tmpmap["Base System"] = 1;
		else if ( _loc == "x" )		_tmpmap["Base (X Windows)"] = 1;
		else if ( _loc == "e" )		_tmpmap["Desktop (Enlightenment)"] = 1;
		else if ( _loc == "g" )		_tmpmap["Desktop (Gnome)"] = 1;
		else if ( _loc == "kde" )	_tmpmap["Desktop (KDE)"] = 1;
		else if ( _loc == "games" )	_tmpmap["Games"] = 1;
		else if ( _loc == "l" )		_tmpmap["Libraries"] = 1;
		else if ( _loc == "f" )		_tmpmap["Misc. Documentation"] = 1;
		else if ( _loc == "n" )		_tmpmap["Network"] = 1;
		else if ( _loc == "s" )		_tmpmap["Network (Web Server)"] = 1;
		else if ( _loc == "d" )		_tmpmap["Programming Tools"] = 1;
		else if ( _loc == "restricted")	_tmpmap["Restricted"] = 1;
		else if ( _loc == "tcl" )	_tmpmap["Tcl/tk"] = 1;
		else if ( _loc == "t" )		_tmpmap["teTeX"] = 1;
	}
	for ( std::map<Glib::ustring, int>::iterator _iter = _tmpmap.begin(); _iter != _tmpmap.end(); ++_iter ) {
		_row = *(_RefModel->append());
		_row[_ColPkgCat] = _iter->first;
	}
}

void CGtkPkgCatView::BuildMirrorCatList(packagemap_t& packages)
{
	_RefModel->clear();
	Gtk::TreeModel::Row	_row = *(_RefModel->append());
	_row[_ColPkgCat] = "All";
	_TreeView.get_selection()->select(_row);	// Start off with the "All" category selected

	// Iterate through the package list and create categories based
	// on the "location" of each package.
	std::map<Glib::ustring, int>	_tmpmap;
	for ( packagemap_t::iterator _iter = packages.begin(); _iter != packages.end(); ++_iter ) {
		if ( !_iter->second.location.find("local://") )
			_tmpmap["Local Mirror"] = 1;
		else if ( _iter->second.location != "All" )
			_tmpmap[_iter->second.location] = 1;
	}
	for ( std::map<Glib::ustring, int>::iterator _iter = _tmpmap.begin(); _iter != _tmpmap.end(); ++_iter ) {
		_row = *(_RefModel->append());
		_row[_ColPkgCat] = _iter->first;
	}
}

Gtk::TreeView* CGtkPkgCatView::GetTreeView()
{
	return &_TreeView;
}

Glib::ustring CGtkPkgCatView::GetCurrentCategory()
{	// Returns the name of the category we are currently viewing.
	Gtk::TreeModel::iterator	_pkgiter = _TreeView.get_selection()->get_selected();
	if ( _pkgiter ) return (*_pkgiter)[_ColPkgCat];
	return "";
}


#endif
